@@ -1,6 +1,6 @@
 """
 Extracted from django.utils.regex_helper for use in short scripts
-without requiring a Djanog dependency.
+without requiring a Django dependency.
 """
 import re
 from .functional import SimpleLazyObject
@@ -14,7 +14,7 @@ def lazy_re_compile(regex, flags=0):
         if isinstance(regex, (str, bytes)):
             return re.compile(regex, flags)
         else:
-            assert not flags, ('flags must be empty if regex is passed pre-compiled')
+            assert not flags, 'flags must be empty if regex is passed pre-compiled'
             return regex
 
     return SimpleLazyObject(_compile)
